@@ -1,17 +1,16 @@
 import mock
-from service.app import Service
-from service.stats.boot_time import Boot
+from service_stats import Boot, ServiceStats
 
 
 def test_serve_data():
-    result = Service.serve_data(Boot)
+    result = ServiceStats.serve_data(Boot)
     assert 'Boot Time' in result
 
 
-@mock.patch('service.slack.Slack.message')
+@mock.patch('service_stats.slack.Slack.message')
 def test_app_slack(mock_slack):
-    result = Service.run(boot=True, cpu=True, disk=True,
-                         memory=True, network=True, system=True, slack=True)
+    result = ServiceStats.run(boot=True, cpu=True, disk=True,
+                              memory=True, network=True, system=True, slack=True)
     assert 'SERVICE' in result
     assert 'Boot Time' in result
     assert 'CPU Info' in result
@@ -22,10 +21,10 @@ def test_app_slack(mock_slack):
     mock_slack.assert_called_once()
 
 
-@mock.patch('service.slack.Slack.message')
+@mock.patch('service_stats.slack.Slack.message')
 def test_app_no_slack(mock_slack):
-    result = Service.run(boot=True, cpu=True, disk=True,
-                         memory=True, network=True, system=True, slack=False)
+    result = ServiceStats.run(boot=True, cpu=True, disk=True,
+                              memory=True, network=True, system=True, slack=False)
     assert 'SERVICE' in result
     assert 'Boot Time' in result
     assert 'CPU Info' in result
