@@ -1,6 +1,6 @@
-from service.stats.cpu import Cpu
+from service_stats import Cpu
 
 
 def test_cpu_serve():
-    result = Cpu.serve()
+    result = Cpu.serve_data()
     assert 'CPU Information' in result
