@@ -1,6 +1,6 @@
-from service.stats.memory import Memory
+from service_stats import Memory
 
 
 def test_memory_serve():
-    result = Memory.serve()
+    result = Memory.serve_data()
     assert 'Memory Information' in result
