@@ -1,6 +1,6 @@
-from service.stats.network import Network
+from service_stats import Network
 
 
 def test_network_serve():
-    result = Network.serve()
+    result = Network.serve_data()
     assert 'Network Information' in result
